@@ -46,6 +46,7 @@ struct _GisPasswordPagePrivate
   GtkWidget *password_explanation;
   GtkWidget *confirm_explanation;
   gboolean valid_confirm;
+  gboolean valid_password;
   guint timeout_id;
   const gchar *username;
 };
@@ -58,7 +59,7 @@ page_validate (GisPasswordPage *page)
 {
   GisPasswordPagePrivate *priv = gis_password_page_get_instance_private (page);
 
-  return priv->valid_confirm;
+  return priv->valid_confirm && priv->valid_password;
 }
 
 static void
@@ -135,6 +136,10 @@ validate (GisPasswordPage *page)
   gtk_label_set_label (GTK_LABEL (priv->confirm_explanation), "");
   priv->valid_confirm = FALSE;
 
+  priv->valid_password = (strength_level > 0);
+  if (priv->valid_password)
+    set_entry_validation_checkmark (GTK_ENTRY (priv->password_entry));
+
   if (strlen (password) > 0 && strlen (verify) > 0) {
     priv->valid_confirm = (strcmp (password, verify) == 0);
     if (!priv->valid_confirm) {
@@ -168,6 +173,7 @@ password_changed (GtkWidget      *w,
   clear_entry_validation_error (GTK_ENTRY (w));
   clear_entry_validation_error (GTK_ENTRY (priv->confirm_entry));
 
+  priv->valid_password = FALSE;
   update_page_validation (page);
 
   if (priv->timeout_id != 0)
