@@ -417,6 +417,8 @@ stop_geolocation (GisTimezonePage *page)
       g_clear_object (&priv->geoclue_cancellable);
     }
 
+  if (priv->geoclue_client)
+    geoclue_client_call_stop (priv->geoclue_client, NULL, NULL, NULL);
   g_clear_object (&priv->geoclue_client);
   g_clear_object (&priv->geoclue_manager);
 }
@@ -452,6 +454,8 @@ gis_timezone_page_constructed (GObject *object)
     exit (1);
   }
 
+  priv->geoclue_cancellable = g_cancellable_new ();
+
   set_auto_location (page, NULL);
   set_location (page, NULL);
   get_location_from_geoclue_async (page);
